package com.ys.bdtp.adm

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Surface
import androidx.compose.runtime.Composable
import androidx.compose.runtime.SideEffect
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import com.google.accompanist.insets.ProvideWindowInsets
import com.google.accompanist.systemuicontroller.rememberSystemUiController
import com.ys.bdtp.adm.app.theme.AdmTheme
import com.ys.bdtp.adm.di.di
import com.ys.bdtp.adm.mvvm.ui.screen.cad.CadHeadMiddle
import org.kodein.di.compose.onDIContext
import org.kodein.di.compose.withDI

@Composable
fun App() = withDI(di(LocalContext.current)) {

    onDIContext(LocalContext.current) {
        val systemUiController = rememberSystemUiController()
        val useDarkIcons = MaterialTheme.colors.isLight

        AdmTheme() {
            ProvideWindowInsets {
                Surface(color = MaterialTheme.colors.background) {
                    SideEffect {
                        systemUiController.setNavigationBarColor(
                            color = Color.Transparent,
                            darkIcons = useDarkIcons,
                        )

                        systemUiController.setStatusBarColor(
                            color = Color.Transparent,
                            darkIcons = useDarkIcons,
                        )
                    }
                    Column {
                        Spacer(Modifier.height(39.dp))
                        CadHeadMiddle()
                    }

                }
            }
        }
    }
}